"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.createValue = exports.getOptionLabel = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _formFieldGrid = _interopRequireDefault(require("../form-field-grid/form-field-grid"));

var _validationError = require("../validation-error/validation-error");

var _propTypesTemplates = require("@data-driven-forms/common/prop-types-templates");

var _select = _interopRequireDefault(require("@data-driven-forms/common/select"));

var _parseInternalValue = _interopRequireDefault(require("@data-driven-forms/common/select/parse-internal-value"));

var _useFieldApi2 = _interopRequireDefault(require("@data-driven-forms/react-form-renderer/use-field-api"));

var _TextField = _interopRequireDefault(require("@material-ui/core/TextField"));

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _ArrowDropDown = _interopRequireDefault(require("@material-ui/icons/ArrowDropDown"));

var _Autocomplete = _interopRequireDefault(require("@material-ui/lab/Autocomplete"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

/**
 * Returns label of selected option
 * @param {Object|Array} option currently selected option
 * @param {Array<Object>} options all options avaiable
 * @returns {String}
 */
var _getOptionLabel = function getOptionLabel(option, options) {
  if (typeof option === 'undefined') {
    return '';
  }

  if (option === '') {
    return '';
  }

  if (Array.isArray(option) && option.length === 0) {
    return '';
  }

  if ((0, _typeof2["default"])(option) === 'object') {
    return option.label;
  }

  var item = options.find(function (_ref) {
    var value = _ref.value;
    return value === option;
  });
  return item && item.label || '';
};
/**
 * Function that creates correct DDF select value format
 * @param {Object|Array} option currently selected values
 * @param {Boolean} isMulti multiple select flag
 * @returns {Object|Array<Object>}
 */


exports.getOptionLabel = _getOptionLabel;

var createValue = function createValue(option, isMulti) {
  if (isMulti) {
    return Array.isArray(option) ? option.map(function (item) {
      return (0, _typeof2["default"])(item) === 'object' ? item : {
        value: item
      };
    }) : option;
  }

  return option;
};

exports.createValue = createValue;

var InternalSelect = function InternalSelect(_ref2) {
  var value = _ref2.value,
      options = _ref2.options,
      label = _ref2.label,
      helperText = _ref2.helperText,
      validateOnMount = _ref2.validateOnMount,
      meta = _ref2.meta,
      isSearchable = _ref2.isSearchable,
      description = _ref2.description,
      classNamePrefix = _ref2.classNamePrefix,
      isMulti = _ref2.isMulti,
      placeholder = _ref2.placeholder,
      _onInputChange = _ref2.onInputChange,
      isFetching = _ref2.isFetching,
      noOptionsMessage = _ref2.noOptionsMessage,
      hideSelectedOptions = _ref2.hideSelectedOptions,
      closeMenuOnSelect = _ref2.closeMenuOnSelect,
      required = _ref2.required,
      _onChange = _ref2.onChange,
      onFocus = _ref2.onFocus,
      onBlur = _ref2.onBlur,
      FormFieldGridProps = _ref2.FormFieldGridProps,
      _ref2$TextFieldProps = _ref2.TextFieldProps,
      textFieldInputProps = _ref2$TextFieldProps.inputProps,
      TextFieldProps = (0, _objectWithoutProperties2["default"])(_ref2$TextFieldProps, ["inputProps"]),
      inputProps = _ref2.inputProps,
      isClearable = _ref2.isClearable,
      isDisabled = _ref2.isDisabled,
      rest = (0, _objectWithoutProperties2["default"])(_ref2, ["value", "options", "label", "helperText", "validateOnMount", "meta", "isSearchable", "description", "classNamePrefix", "isMulti", "placeholder", "onInputChange", "isFetching", "noOptionsMessage", "hideSelectedOptions", "closeMenuOnSelect", "required", "onChange", "onFocus", "onBlur", "FormFieldGridProps", "TextFieldProps", "inputProps", "isClearable", "isDisabled"]);
  var invalid = (0, _validationError.validationError)(meta, validateOnMount);
  var internalValue = (0, _parseInternalValue["default"])(value, isMulti);
  return /*#__PURE__*/_react["default"].createElement(_formFieldGrid["default"], FormFieldGridProps, /*#__PURE__*/_react["default"].createElement(_Autocomplete["default"], (0, _extends2["default"])({
    filterSelectedOptions: hideSelectedOptions,
    disabled: isDisabled,
    disableClearable: isClearable,
    popupIcon: isFetching ? /*#__PURE__*/_react["default"].createElement(_CircularProgress["default"], {
      size: 20,
      color: "inherit"
    }) : /*#__PURE__*/_react["default"].createElement(_ArrowDropDown["default"], null),
    fullWidth: true
  }, rest, {
    renderInput: function renderInput(params) {
      return /*#__PURE__*/_react["default"].createElement(_TextField["default"], (0, _extends2["default"])({
        onFocus: onFocus,
        onBlur: onBlur
      }, params, {
        required: required,
        error: !!invalid,
        helperText: invalid || (meta.touched || validateOnMount) && meta.warning || helperText || description,
        label: label,
        margin: "normal"
      }, TextFieldProps, {
        inputProps: _objectSpread(_objectSpread(_objectSpread(_objectSpread({}, params.inputProps), textFieldInputProps), inputProps), {}, {
          readOnly: !isSearchable,
          placeholder: !internalValue || internalValue.length === 0 ? placeholder : undefined
        })
      }));
    },
    noOptionsText: noOptionsMessage(),
    onInputChange: function onInputChange(_event, value) {
      return _onInputChange(value);
    },
    options: options,
    multiple: isMulti,
    getOptionLabel: function getOptionLabel(option) {
      return _getOptionLabel(option, options);
    },
    value: typeof internalValue === 'undefined' ? null : internalValue,
    onChange: function onChange(_event, option) {
      return _onChange(createValue(option, isMulti));
    },
    loading: isFetching
  })));
};

InternalSelect.propTypes = {
  meta: _propTypesTemplates.meta,
  placeholder: _propTypes["default"].node,
  label: _propTypes["default"].node,
  helperText: _propTypes["default"].node,
  validateOnMount: _propTypes["default"].bool,
  isSearchable: _propTypes["default"].bool,
  options: _propTypes["default"].arrayOf(_propTypes["default"].shape({
    value: _propTypes["default"].any.isRequired,
    label: _propTypes["default"].node.isRequired
  })).isRequired,
  description: _propTypes["default"].node,
  FormFieldGridProps: _propTypes["default"].object,
  value: _propTypes["default"].any,
  isClearable: _propTypes["default"].bool,
  classNamePrefix: _propTypes["default"].string,
  isMulti: _propTypes["default"].bool,
  loadingMessage: _propTypes["default"].node,
  onInputChange: _propTypes["default"].func,
  isFetching: _propTypes["default"].bool,
  noOptionsMessage: _propTypes["default"].func,
  closeMenuOnSelect: _propTypes["default"].bool,
  onChange: _propTypes["default"].func.isRequired,
  hideSelectedOptions: _propTypes["default"].bool,
  required: _propTypes["default"].bool,
  onFocus: _propTypes["default"].func,
  onBlur: _propTypes["default"].func,
  TextFieldProps: _propTypes["default"].object,
  inputProps: _propTypes["default"].object,
  isDisabled: _propTypes["default"].bool
};
InternalSelect.defaultProps = {
  placeholder: 'Please choose',
  FormFieldGridProps: {},
  TextFieldProps: {},
  inputProps: {},
  loadingText: 'Loading...'
};

var Select = function Select(props) {
  var _useFieldApi = (0, _useFieldApi2["default"])(props),
      input = _useFieldApi.input,
      isRequired = _useFieldApi.isRequired,
      isDisabled = _useFieldApi.isDisabled,
      isReadOnly = _useFieldApi.isReadOnly,
      disabled = _useFieldApi.disabled,
      multiple = _useFieldApi.multiple,
      isMulti = _useFieldApi.isMulti,
      isClearable = _useFieldApi.isClearable,
      disableClearable = _useFieldApi.disableClearable,
      loadingMessage = _useFieldApi.loadingMessage,
      loadingText = _useFieldApi.loadingText,
      noOptionsMessage = _useFieldApi.noOptionsMessage,
      noOptionsText = _useFieldApi.noOptionsText,
      closeMenuOnSelect = _useFieldApi.closeMenuOnSelect,
      rest = (0, _objectWithoutProperties2["default"])(_useFieldApi, ["input", "isRequired", "isDisabled", "isReadOnly", "disabled", "multiple", "isMulti", "isClearable", "disableClearable", "loadingMessage", "loadingText", "noOptionsMessage", "noOptionsText", "closeMenuOnSelect"]);

  return /*#__PURE__*/_react["default"].createElement(_select["default"], (0, _extends2["default"])({}, input, {
    isMulti: multiple || isMulti,
    required: isRequired,
    disabled: isDisabled || isReadOnly || disabled,
    disableClearable: !isClearable || disableClearable,
    loadingText: loadingMessage || loadingText,
    noOptionsMessage: noOptionsMessage || noOptionsText
  }, rest, {
    SelectComponent: InternalSelect
  }));
};

var _default = Select;
exports["default"] = _default;